ActivityError

Enum ActivityError 

pub enum ActivityError {
    Retryable {
        source: Error,
        explicit_delay: Option<Duration>,
    },
    Cancelled {
        details: Option<Payload>,
    },
    NonRetryable(Error),
}
Returned as errors from activity functions

Variants



Retryable

This error can be returned from activities to allow the explicit configuration of certain error properties. It’s also the default error type that arbitrary errors will be converted into.

Fields

source: Error

The underlying error

explicit_delay: Option<Duration>

If specified, the next retry (if there is one) will occur after this delay



Cancelled

Return this error to indicate your activity is cancelling

Fields

details: Option<Payload>

Some data to save as the cancellation reason



NonRetryable(Error)

Return this error to indicate that your activity non-retryable this is a transparent wrapper around anyhow Error so essentially any type of error could be used here.

Implementations

Source

impl ActivityError

pub fn cancelled() -> Self

Construct a cancelled error without details