NexusOperationOptions

Struct NexusOperationOptions 

pub struct NexusOperationOptions {
    pub endpoint: String,
    pub service: String,
    pub operation: String,
    pub input: Option<Payload>,
    pub schedule_to_close_timeout: Option<Duration>,
    pub nexus_header: HashMap<String, String>,
    pub cancellation_type: Option<NexusOperationCancellationType>,
}
Options for Nexus Operations

Fields

endpoint: String

Endpoint name, must exist in the endpoint registry or this command will fail.

service: String

Service name.

operation: String

Operation name.

input: Option<Payload>

Input for the operation. The server converts this into Nexus request content and the appropriate content headers internally when sending the StartOperation request. On the handler side, if it is also backed by Temporal, the content is transformed back to the original Payload sent in this command.

schedule_to_close_timeout: Option<Duration>

Schedule-to-close timeout for this operation. Indicates how long the caller is willing to wait for operation completion. Calls are retried internally by the server.

nexus_header: HashMap<String, String>

Header to attach to the Nexus request. Users are responsible for encrypting sensitive data in this header as it is stored in workflow history and transmitted to external services as-is. This is useful for propagating tracing information. Note these headers are not the same as Temporal headers on internal activities and child workflows, these are transmitted to Nexus operations that may be external and are not traditional payloads.

cancellation_type: Option<NexusOperationCancellationType>

Cancellation type for the operation