Worker

Struct Worker 

pub struct Worker { /* private fields */ }
A worker that can poll for and respond to workflow tasks by using WorkflowFunctions, and activity tasks by using ActivityFunctions

Implementations

Source

impl Worker

pub fn new_from_core( worker: Arc<dyn CoreWorker>, task_queue: impl Into<String>, ) -> Self

Create a new Rust SDK worker from a core worker

pub fn task_queue(&self) -> &str

Returns the task queue name this worker polls on

pub fn shutdown_handle(&self) -> impl Fn() + use<>

Return a handle that can be used to initiate shutdown. TODO: Doc better after shutdown changes

pub fn register_wf( &mut self, workflow_type: impl Into<String>, wf_function: impl Into<WorkflowFunction>, )

Register a Workflow function to invoke when the Worker is asked to run a workflow of workflow_type

pub fn register_activity<A, R, O>( &mut self, activity_type: impl Into<String>, act_function: impl IntoActivityFunc<A, R, O>, )

Register an Activity function to invoke when the Worker is asked to run an activity of activity_type

pub fn insert_app_data<T: Send + Sync + 'static>(&mut self, data: T)

Insert Custom App Context for Workflows and Activities

pub async fn run(&mut self) -> Result<(), Error>

Runs the worker. Eventually resolves after the worker has been explicitly shut down, or may return early with an error in the event of some unresolvable problem.

pub fn set_worker_interceptor( &mut self, interceptor: impl WorkerInterceptor + 'static, )

pub fn with_new_core_worker(&mut self, new_core_worker: Arc<dyn CoreWorker>)

Turns this rust worker into a new worker with all the same workflows and activities registered, but with a new underlying core worker. Can be used to swap the worker for a replay worker, change task queues, etc.

pub fn cached_workflows(&self) -> usize

Returns number of currently cached workflows as understood by the SDK. Importantly, this is not the same as understood by core, though they should always be in sync.