pub struct ActContext { /* private fields */ }Expand description
Used within activities to get info, heartbeat management etc.
Implementations
Sourceimpl ActContext
impl ActContext
Sourcepub async fn cancelled(&self)
pub async fn cancelled(&self)
Returns a future the completes if and when the activity this was called inside has been cancelled
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Returns true if this activity has already been cancelled
Sourcepub fn extra_inputs(&mut self) -> &mut [Payload]
pub fn extra_inputs(&mut self) -> &mut [Payload]
Retrieve extra parameters to the Activity. The first input is always popped and passed to the Activity function for the currently executing activity. However, if more parameters are passed, perhaps from another language’s SDK, explicit access is available from extra_inputs
Sourcepub fn get_heartbeat_details(&self) -> &[Payload]
pub fn get_heartbeat_details(&self) -> &[Payload]
Extract heartbeat details from last failed attempt. This is used in combination with retry policy.
Sourcepub fn record_heartbeat(&self, details: Vec<Payload>)
pub fn record_heartbeat(&self, details: Vec<Payload>)
RecordHeartbeat sends heartbeat for the currently executing activity