pub trait IntoUpdateValidatorFunc<Arg> {
// Required method
fn into_update_validator_fn(
self,
) -> Box<dyn Fn(&UpdateInfo, &Payload) -> Result<(), Error> + Send>;
}Expand description
Closures / functions which can be turned into update validation functions implement this trait
Required Methods
Sourcefn into_update_validator_fn(
self,
) -> Box<dyn Fn(&UpdateInfo, &Payload) -> Result<(), Error> + Send>
fn into_update_validator_fn( self, ) -> Box<dyn Fn(&UpdateInfo, &Payload) -> Result<(), Error> + Send>
Consume the closure/fn pointer and turn it into an update validator